@@ -3,9 +3,9 @@ Test the transformers for all of the currently supported events into xAPI format
 """
 import json
 import os
+from unittest.mock import patch
 
 from django.test import TestCase
-from mock import patch
 
 from event_routing_backends.processors.tests.transformers_test_mixin import TransformersTestMixin
 from event_routing_backends.processors.xapi.registry import XApiTransformersRegistry
